NEO4J_DATABASES = {
    'default' : {
        'HOST':'localhost',
        'PORT':7474,
        'ENDPOINT':'/db/data'
    }
}

DEBUG = True

NEO4DJANGO_PROFILE_REQUESTS = False

NEO4J_DELETE_KEY = 'supersecretdebugkey!'
